use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Barr
Christiansen
DROLSKY
DROLSKY's
Dave
Florian
Graham
Koston
Local
Nick
PayPal
Ragwitz
Rolsky
Rolsky's
Time
Unknown
autarch
drolsky
google
lib
nick
nocheck
rafl
unknown
